#ifndef tempname_h
#define tempname_h
/*
** Copyright 2001-2003 Double Precision, Inc.  See COPYING for
** distribution information.
*/

static const char tempname_h_rcsid[]="$Id: tempname.h,v 1.2 2003/06/02 15:51:23 mrsam Exp $";

#include "config.h"

#ifdef  __cplusplus
extern "C" {
#endif

#define TEMPNAMEBUFSIZE	64

int libmail_tempfile(char *);

#ifdef  __cplusplus
} ;
#endif

#endif
